/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsICacheEntry;

[scriptable, uuid(692dda47-3b21-4d0d-853a-f4d27cc324d0)]
interface nsICacheStorageVisitor : nsISupports
{
  /**
   */
  void onCacheStorageInfo(in uint32_t aEntryCount, in uint64_t aConsumption);

  /**
   */
  void onCacheEntryInfo(in nsICacheEntry aEntry);

  /**
   */
  void onCacheEntryVisitCompleted();
};
