/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIX509CertList;

/**
 * This represents a service to access and manipulate 
 * X.509 certificates stored in a database through methods
 * not in nsIX509CertDB, which is frozen
 *
 */
[scriptable, uuid(e0df4784-6560-45bf-b1b7-86076a0e8381)]
interface nsIX509CertDB2 : nsISupports {

  /* 
   * Add a cert to a cert DB from a base64 encoded string.
   *
   * @param base64 The raw representation of a certificate,
   *                encoded as Base 64.
   * @param aTrust decoded by CERT_DecodeTrustString. 3 comma separated characters,
   *                indicating SSL, Email, and Obj signing trust
   * @param aName name of the cert for display purposes.
   */
  void addCertFromBase64(in string base64, in string aTrust, in string aName);

  /*
   * Get all the known certs in the database
   */
  nsIX509CertList getCerts();
};

