/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
#include "nsISupports.idl"

[scriptable, uuid(b8cc9126-9319-4415-afd9-b82220d453ed)]
interface nsISecurityInfoProvider : nsISupports
{
  /**
   * The security info for this provider, if any.
   */
  readonly attribute nsISupports securityInfo;

  /**
   * Whether this provider has transferred data.  If it hasn't, its
   * security info should be ignored.
   */
  readonly attribute boolean hasTransferredData;
};
