/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_FileBinding_h__
#define mozilla_dom_FileBinding_h__

#include "BlobBinding.h"
#include "js/RootingAPI.h"
#include "jspubtd.h"
#include "mozilla/ErrorResult.h"
#include "mozilla/dom/BindingDeclarations.h"

namespace mozilla {
namespace dom {

struct FilePropertyBagAtoms;
class NativePropertyHooks;

} // namespace dom
} // namespace mozilla

namespace mozilla {
namespace dom {

struct FilePropertyBag : public BlobPropertyBag
{
  nsString mName;

  inline FilePropertyBag()
  {
  }

  explicit inline FilePropertyBag(const FilePropertyBag& aOther)
  {
    *this = aOther;
  }

  bool
  Init(JSContext* cx, JS::Handle<JS::Value> val, const char* sourceDescription = "Value");

  bool
  Init(const nsAString& aJSON);

  bool
  ToObject(JSContext* cx, JS::Handle<JSObject*> parentObject, JS::MutableHandle<JS::Value> rval) const;

  void
  TraceDictionary(JSTracer* trc);

  void
  operator=(const FilePropertyBag& aOther);

private:
  static bool
  InitIds(JSContext* cx, FilePropertyBagAtoms* atomsCache);
};
struct FilePropertyBagInitializer : public FilePropertyBag
{
  FilePropertyBagInitializer();
};


} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_FileBinding_h__
